#!/bin/bash
# AppRun script for GoogleChrome Rox-style AppDir
# Copyright 2013 Gilbert Ashley <amigo@ibiblio.org>
# This script is released under the GNU General Public License Version 2.
# Anyone is free to use and/or modify this program for their own use.

# If you modify it and distribute it, please leave the above Copyright
# notice intact and add your own below, like this:
# Copyright ???? Your Name <your email address>
# This is a modified version of the original program.
# Please do not bother the original author if you
# are experiencing problems with it, or have found a bug.
# List your changes here:
#

# This AppDir sets up a union mount/filesystem and then chroots into it
# to execute the program without having to install the program.
# It uses unionfs-fuse and fakechroot programs for the real work.

# we need to know where this AppDir is
HERE=$(dirname $0)

# Both the write directory and the mount-point for the union need
# to be writable by the user and, at best,  should be unique to this app
mkdir -p $HOME/Choices/GoogleChrome/write
mkdir -p $HOME/Choices/GoogleChrome/union

# Create the union. It consists of 3 layers:
# The read-write directory (write) -must be writable by the user
# The package content (app) takes precendence over the system
# The easiest approach is to make all of the root '/' available
# Some applications might still require 'mount --bind', before and/or after the union is mounted,
# in order to amke their contents properly available inside the chroot.
# Or individual directories can be bind'ed in the union, instead of layering '/'
unionfs-fuse -o nonempty -o allow_root -o cow $HOME/Choices/GoogleChrome/write=RW:$HERE/app=RO:/=RO $HOME/Choices/GoogleChrome/union
# Since the 'app' directory takes precedence over any files in '/', you can include newer or
# different versions of system libs right in the 'app' dir -or any libraries required by
# this program which are not in the main system ('/').

# chroot into the union mount and execute the desired program
fakechroot chroot $HOME/Choices/GoogleChrome/union /usr/bin/google-chrome --no-sandbox 2> /dev/null
# a normal manual chroot might do this instead:
# fakechroot chroot union /bin/sh
# Note that we cannot use 'exec fakechroot ...' because we need to clean up
# and undo the union mount after the program is executed.
# We also cannot background the program 'fakechroot ... &' because
# we also need to wait for the program to exit before cleaning up

# undo the unionfs mount
fusermount -u $HOME/Choices/GoogleChrome/union

# The google-chrome program leaves behind 2  bad links and 1 socket 
# The program cannot be re-started if these are not removed
rm -f $HOME/.config/google-chrome/Singleton*
# there is also a file $HOME/.config/google-chrome/chrome_shutdown_ms.txt
rm -f $HOME/.config/google-chrome/chrome_shutdown_ms.txt
